API docs for “spamfighter.api.model.test.test_train.ModelTrainCommandTestCase”

# Class s.a.m.t.t.ModelTrainCommandTestCase(unittest.TestCase):

Part of spamfighter.api.model.test.test_train View Source View In Hierarchy

Тест на `spamfighter.api.model.train.ModelTrainCommand`.

Method | setUp | Undocumented
Method | tearDown | Undocumented
Method | testRun | Undocumented
Method | testBadMarker | Undocumented

def setUp(self): (source)
Undocumented
def tearDown(self): (source)
Undocumented
def testRun(self): (source)
Undocumented
def testBadMarker(self): (source)
Undocumented